@@ -72,16 +72,15 @@ def write_td(element, writer, styler, style):
     logger.debug("Writing <td> at {}".format(writer.ref))
     style = styler.get_style(element) or style
     with writer.record() as recording:
-        children = [child for child in element.content()]
+        if element.text:
+            data_type = _type_map[element.attrs.get("data-type")]
+            logger.debug("Setting cell {} to {}".format(writer.ref, data_type))
+            write_value(data_type(element.text.strip()), writer, styler, style)
 
+        children = [child for child in element.content()]
         for child in children:
-            if child.text:
-                data_type = _type_map[child.attrs.get("data-type")]
-                logger.debug("Setting cell {} to {}".format(writer.ref, data_type))
-                write_value(data_type(child.text.strip()), writer, styler, style)
-            else:
-                logging.debug("Recursing into element {}".format(child.name))
-                write(child, writer, styler, style)
+            logging.debug("Recursing into element {}".format(child.name))
+            write(child, writer, styler, style)
 
     return element, recording
 
@@ -199,12 +198,20 @@ def write_string(element, writer, styler, style):
 @return_cursor(CursorStrategy.top_right)
 def write_input(element, writer, styler, style):
     logger.debug("Writing <input> at {}".format(writer.ref))
+    style = styler.get_style(element) or style
 
+    recording = []
     list_validation = element.get("list", None)
     if list_validation:
         writer.add_validation_to_cell(list_validation)
+        with writer.record() as recording:
+            data_type = _type_map[element.attrs.get("data-type")]
+            list_default_value = element.attrs.get("value", "")
 
-    return element, []
+            logger.debug("Setting cell {} to {}".format(writer.ref, data_type))
+            write_value(data_type(list_default_value.strip()), writer, styler, style)
+
+    return element, recording
 
 
 def create_datavalidation(element, writer, styler, style):
